aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sql/core/src/main/scala/org/apache/spark/sql/SQLContext.scala36
1 files changed, 18 insertions, 18 deletions
diff --git a/sql/core/src/main/scala/org/apache/spark/sql/SQLContext.scala b/sql/core/src/main/scala/org/apache/spark/sql/SQLContext.scala
index 23f2b6e894..6fcc9bb447 100644
--- a/sql/core/src/main/scala/org/apache/spark/sql/SQLContext.scala
+++ b/sql/core/src/main/scala/org/apache/spark/sql/SQLContext.scala
@@ -609,51 +609,51 @@ class SQLContext private[sql](val sparkSession: SparkSession)
/**
* :: Experimental ::
* Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
* in a range from 0 to `end` (exclusive) with step value 1.
*
- * @since 2.0.0
- * @group dataset
+ * @since 1.4.1
+ * @group dataframe
*/
@Experimental
- def range(end: Long): Dataset[java.lang.Long] = sparkSession.range(end)
+ def range(end: Long): DataFrame = sparkSession.range(end).toDF()
/**
* :: Experimental ::
* Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
* in a range from `start` to `end` (exclusive) with step value 1.
*
- * @since 2.0.0
- * @group dataset
+ * @since 1.4.0
+ * @group dataframe
*/
@Experimental
- def range(start: Long, end: Long): Dataset[java.lang.Long] = sparkSession.range(start, end)
+ def range(start: Long, end: Long): DataFrame = sparkSession.range(start, end).toDF()
/**
* :: Experimental ::
* Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
* in a range from `start` to `end` (exclusive) with a step value.
*
* @since 2.0.0
- * @group dataset
+ * @group dataframe
*/
@Experimental
- def range(start: Long, end: Long, step: Long): Dataset[java.lang.Long] = {
- sparkSession.range(start, end, step)
+ def range(start: Long, end: Long, step: Long): DataFrame = {
+ sparkSession.range(start, end, step).toDF()
}
/**
* :: Experimental ::
* Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
* in a range from `start` to `end` (exclusive) with a step value, with partition number
* specified.
*
- * @since 2.0.0
- * @group dataset
+ * @since 1.4.0
+ * @group dataframe
*/
@Experimental
- def range(start: Long, end: Long, step: Long, numPartitions: Int): Dataset[java.lang.Long] = {
- sparkSession.range(start, end, step, numPartitions)
+ def range(start: Long, end: Long, step: Long, numPartitions: Int): DataFrame = {
+ sparkSession.range(start, end, step, numPartitions).toDF()
}
/**
@@ -609,51 +609,51 @@ class SQLContext private[sql](val sparkSession: SparkSession)
/**
* :: Experimental ::
- * Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
+ * Creates a [[DataFrame]] with a single [[LongType]] column named `id`, containing elements
* in a range from 0 to `end` (exclusive) with step value 1.
*
@@ -609,51 +609,51 @@ class SQLContext private[sql](val sparkSession: SparkSession)
/**
* :: Experimental ::
- * Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
+ * Creates a [[DataFrame]] with a single [[LongType]] column named `id`, containing elements
* in a range from `start` to `end` (exclusive) with step value 1.
*
@@ -609,51 +609,51 @@ class SQLContext private[sql](val sparkSession: SparkSession)
/**
* :: Experimental ::
- * Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
+ * Creates a [[DataFrame]] with a single [[LongType]] column named `id`, containing elements
* in a range from `start` to `end` (exclusive) with a step value.
*
@@ -609,51 +609,51 @@ class SQLContext private[sql](val sparkSession: SparkSession)
/**
* :: Experimental ::
- * Creates a [[Dataset]] with a single [[LongType]] column named `id`, containing elements
- * in a range from `start` to `end` (exclusive) with a step value, with partition number
+ * Creates a [[DataFrame]] with a single [[LongType]] column named `id`, containing elements
+ * in an range from `start` to `end` (exclusive) with an step value, with partition number
* specified.
*